@@ -1,5 +1,5 @@
 /*
- * $Id: dbdimp.h 13771 2010-01-26 13:46:22Z mjevans $
+ * $Id: dbdimp.h 14272 2010-07-22 18:33:08Z mjevans $
  * portions Copyright (c) 2007-2008 Martin J. Evans
  * Copyright (c) 1997-2001 Jeff Urlwin
  * portions Copyright (c) 1997  Thomas K. Wenrich
@@ -13,6 +13,8 @@
  *
  */
 
+/* some constants for driver specific types */
+#define MS_SQLS_XML_TYPE -152
 
 typedef struct imp_fbh_st imp_fbh_t;
 
@@ -109,7 +111,8 @@ struct imp_sth_st {
     SQLHSTMT   hstmt;
 
     int        moreResults;	/* are there more results to fetch?	*/
-    int        done_desc;	/* have we described this sth yet ?	*/
+    int        done_desc;	/* have we described this sth yet?	*/
+    int        done_bind;       /* have we bound the columns yet? */
 
     /* Input Details	*/
     char      *statement;	/* sql (see sth_scan)		*/
@@ -121,6 +124,7 @@ struct imp_sth_st {
 				 * by ptrs from within the fbh structures
 				 */
     UCHAR    *RowBuffer;	/* holds row data; referenced from fbh */
+    SQLLEN   RowBufferSizeReqd;
     imp_fbh_t *fbh;		/* array of imp_fbh_t structs	*/
 
     SQLLEN   RowCount;		/* Rows affected by insert, update, delete
@@ -167,10 +171,9 @@ struct imp_fbh_st { 	/* field buffer EXPERIMENTAL */
 				 */
     UCHAR *data;		/* points into sth->RowBuffer */
     SQLLEN datalen;		/* length returned from fetch for single row. */
-    UDWORD maxcnt;		/* max num of rows to return per fetch */
-    SV *colary;			/* ref to array to recv output data */
-    SDWORD *col_indics;	/* individual column length/NULL indicators for array binding */
-    int is_array;		/* TRUE => bound to array */
+    unsigned long bind_flags;   /* flags passed to bind_col */
+#define ODBC_TREAT_AS_LOB 0x1
+    IV req_type;                /* type passed to bind_col */
 };
 
 
@@ -204,9 +207,8 @@ struct phs_st {             /* scalar placeholder */
     SQLSMALLINT bp_d_digits;   /* decimal digits */
     SQLULEN bp_column_size;
     SQLLEN bp_buffer_length;
-    
+
     char name[1];           /* struct is malloc'd bigger as needed */
-    
 };
 
 
@@ -243,4 +245,5 @@ struct phs_st {             /* scalar placeholder */
 #define dbd_st_tables		odbc_st_tables
 #define dbd_st_primary_keys	odbc_st_primary_keys
 #define dbd_db_execdirect	odbc_db_execdirect
+#define dbd_st_bind_col     	odbc_st_bind_col
 /* end */
